# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`yum`](#yum): A class to install and manage Yum configuration.
* [`yum::clean`](#yumclean): A $(yum clean all) Exec to be notified if desired.
* [`yum::plugin::post_transaction_actions`](#yumpluginpost_transaction_actions): Class to install post_transaction plugin
* [`yum::plugin::versionlock`](#yumpluginversionlock): This class installs versionlock plugin

### Defined types

* [`yum::config`](#yumconfig): This definition manages yum.conf
* [`yum::gpgkey`](#yumgpgkey): imports/deleted public GPG key for RPM. Key can be stored on Puppet's fileserver or as inline content.
* [`yum::group`](#yumgroup): This definition installs or removes yum package group.
* [`yum::install`](#yuminstall): Installs/removes rpms from local file/URL via yum install command.
* [`yum::plugin`](#yumplugin): This definition installs Yum plugin.
* [`yum::post_transaction_action`](#yumpost_transaction_action): Creates post transaction configuratons for dnf or yum.
* [`yum::versionlock`](#yumversionlock): Locks package from updates.

### Functions

* [`yum::bool2num_hash_recursive`](#yumbool2num_hash_recursive): This functions converts the Boolean values of a Hash to Integers, either '0' or '1'.  It does this recursively, decending as far as the langu

### Data types

* [`Yum::RpmArch`](#yumrpmarch): Valid rpm architectures.
* [`Yum::RpmName`](#yumrpmname): Valid rpm name.
* [`Yum::RpmNameGlob`](#yumrpmnameglob): Valid rpm name with globs.
* [`Yum::RpmRelease`](#yumrpmrelease): Valid rpm release fields.
* [`Yum::RpmVersion`](#yumrpmversion): Valid rpm version fields.
* [`Yum::VersionlockString`](#yumversionlockstring): This type matches strings appropriate for use with yum-versionlock. Its basic format, using the `rpm(8)` query string format, is `%{EPOCH}:%{

### Tasks

* [`init`](#init): Allows you to perform yum functions

## Classes

### <a name="yum"></a>`yum`

A class to install and manage Yum configuration.

#### Examples

##### Enable management of the default repos for a supported OS:

```puppet
---
yum::manage_os_default_repos: true
```

##### Add Hiera data to disable *management* of the CentOS Base repo:

```puppet
---
yum::manage_os_default_repos: true
yum::repo_exclusions:
    - 'base'
```

##### Ensure the CentOS base repo is removed from the agent system(s):

```puppet
---
yum::manage_os_default_repos: true
yum::repos:
    base:
        ensure: 'absent'
```

##### Add a custom repo:

```puppet
---
yum::managed_repos:
    - 'example_repo'
yum::repos:
    example_repo:
        ensure: 'present'
        enabled: true
        descr: 'Example Repo'
        baseurl: 'https://repos.example.com/example/'
        gpgcheck: true
        gpgkey: 'file:///etc/pki/gpm-gpg/RPM-GPG-KEY-Example'
        target: '/etc/yum.repos.d/example.repo'
```

##### Use a custom `baseurl` for the CentOS Base repo:

```puppet
---
yum::manage_os_default_repos: true
yum::repos:
    base:
        baseurl: 'https://repos.example.com/CentOS/base/'
        mirrorlist: '--'
```

#### Parameters

The following parameters are available in the `yum` class:

* [`clean_old_kernels`](#clean_old_kernels)
* [`keep_kernel_devel`](#keep_kernel_devel)
* [`config_options`](#config_options)
* [`repos`](#repos)
* [`managed_repos`](#managed_repos)
* [`manage_os_default_repos`](#manage_os_default_repos)
* [`os_default_repos`](#os_default_repos)
* [`repo_exclusions`](#repo_exclusions)
* [`gpgkeys`](#gpgkeys)
* [`utils_package_name`](#utils_package_name)

##### <a name="clean_old_kernels"></a>`clean_old_kernels`

Data type: `Boolean`

Whether or not to purge old kernel version beyond the `keeponly_limit`.

Default value: ``true``

##### <a name="keep_kernel_devel"></a>`keep_kernel_devel`

Data type: `Boolean`

Whether or not to keep kernel devel packages on old kernel purge.

Default value: ``false``

##### <a name="config_options"></a>`config_options`

Data type: `Hash[String, Variant[String, Integer, Boolean, Hash[String, Variant[String, Integer, Boolean]]]]`

A Hash where keys are the names of `Yum::Config` resources and the values
are either the direct `ensure` value, or a Hash of the resource's attributes.

@note Boolean parameter values will be converted to either a `1` or `0`; use a quoted string to
  get a literal `true` or `false`.

Default value: `{}`

##### <a name="repos"></a>`repos`

Data type: `Hash[String, Optional[Hash[String, Variant[String, Integer, Boolean]]]]`

A hash where keys are the names of `Yumrepo` resources and each value represents its respective
Yumrepo's resource parameters.  This is used in conjunction with the `managed_repos` parameter
to create `Yumrepo` resources en masse.  Some default data is provided for this using module
data.  It is configured to deep merge with a `knockout_prefix` of `--` by default, so individual
parameters may be overriden or removed via global or environment Hiera data.

@note Boolean parameter values will be converted to either a `1` or `0`; use a quoted string to
  get a literal `true` or `false`.

Default value: `{}`

##### <a name="managed_repos"></a>`managed_repos`

Data type: `Array[String]`

An array of first-level keys from the `repos` hash to include in the catalog.  The module uses
this list to select `Yumrepo` resources from the `repos` hash for instantiation.  Defaults are
set in the module's Hiera data.

@note This only indicates the *managed* state of the repos, the `ensure` state must be managed
  in the `repos` data.

Default value: `[]`

##### <a name="manage_os_default_repos"></a>`manage_os_default_repos`

Data type: `Boolean`

Whether or not to add an operating system's default repos to the `managed_repos` array.

@note This only works for operating systems with data in the module's data directory.  Currently
  the module only contains data for for CentOS 6 & 7.

Default value: ``false``

##### <a name="os_default_repos"></a>`os_default_repos`

Data type: `Array[String]`

A list of default repos to add to `managed_repos` if `manage_os_default_repos` is enabled.
Normally this should not be modified.

Default value: `[]`

##### <a name="repo_exclusions"></a>`repo_exclusions`

Data type: `Array[String]`

An array of first-level keys from the `repos` hash to exclude from management via this module.
Values in this array will be subtracted from the `managed_repos` array as a last step before
instantiation.

Default value: `[]`

##### <a name="gpgkeys"></a>`gpgkeys`

Data type: `Hash[String, Hash[String, String]]`

A hash of yum::gpgkey types, which will be automatically included if they
are referenced by a managed_repo. This will use the same merging behavior
as repos.

Default value: `{}`

##### <a name="utils_package_name"></a>`utils_package_name`

Data type: `String`

Name of the utils package, e.g. 'yum-utils', or 'dnf-utils'.

Default value: `'yum-utils'`

### <a name="yumclean"></a>`yum::clean`

A $(yum clean all) Exec to be notified if desired.

### <a name="yumpluginpost_transaction_actions"></a>`yum::plugin::post_transaction_actions`

Class to install post_transaction plugin

* **See also**
  * https://dnf-plugins-core.readthedocs.io/en/latest/post-transaction-actions.html
    * DNF Post Transaction Items

#### Examples

##### Enable post_transaction_action plugin

```puppet
class{'yum::plugin::post_transaction_actions':
  ensure => present,
}
```

#### Parameters

The following parameters are available in the `yum::plugin::post_transaction_actions` class:

* [`ensure`](#ensure)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Should the post_transaction actions plugin be installed

Default value: `'present'`

### <a name="yumpluginversionlock"></a>`yum::plugin::versionlock`

This class installs versionlock plugin

#### Examples

##### Sample usage:

```puppet
include yum::plugin::versionlock
```

#### Parameters

The following parameters are available in the `yum::plugin::versionlock` class:

* [`ensure`](#ensure)
* [`clean`](#clean)
* [`path`](#path)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

specifies if versionlock should be present or absent

Default value: `'present'`

##### <a name="clean"></a>`clean`

Data type: `Boolean`

specifies if yum clean all should be called after edits. Defaults false.

Default value: ``false``

##### <a name="path"></a>`path`

Data type: `String`

filepath for the versionlocks

Default value: `'/etc/yum/pluginconf.d/versionlock.list'`

## Defined types

### <a name="yumconfig"></a>`yum::config`

This definition manages yum.conf

#### Examples

##### configure installonly limit

```puppet
yum::config { 'installonly_limit':
  ensure => 2,
}
```

##### remove a configuration

```puppet
yum::config { 'debuglevel':
  ensure => absent,
}
```

#### Parameters

The following parameters are available in the `yum::config` defined type:

* [`ensure`](#ensure)
* [`key`](#key)

##### <a name="ensure"></a>`ensure`

Data type: `Variant[Boolean, Integer, Enum['absent'], String]`

specifies value or absent keyword

##### <a name="key"></a>`key`

Data type: `String`

alternative conf. key (defaults to name)

Default value: `$title`

### <a name="yumgpgkey"></a>`yum::gpgkey`

imports/deleted public GPG key for RPM. Key can be stored on Puppet's fileserver or as inline content.

#### Examples

##### Sample usage:

```puppet
yum::gpgkey { '/etc/pki/rpm-gpg/RPM-GPG-KEY-puppet-smoketest1':
  ensure  => 'present',
  content => '-----BEGIN PGP PUBLIC KEY BLOCK-----
...
-----END PGP PUBLIC KEY BLOCK-----';
}
```

#### Parameters

The following parameters are available in the `yum::gpgkey` defined type:

* [`path`](#path)
* [`ensure`](#ensure)
* [`content`](#content)
* [`source`](#source)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)

##### <a name="path"></a>`path`

Data type: `String`

alternative file location (defaults to name)

Default value: `$name`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

specifies if key should be present or absent

Default value: `'present'`

##### <a name="content"></a>`content`

Data type: `Optional[String]`

the actual file content

Default value: ``undef``

##### <a name="source"></a>`source`

Data type: `Optional[String]`

source (e.g.: puppet:///)

Default value: ``undef``

##### <a name="owner"></a>`owner`

Data type: `String`

file owner

Default value: `'root'`

##### <a name="group"></a>`group`

Data type: `String`

file group

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `String`

file mode

Default value: `'0644'`

### <a name="yumgroup"></a>`yum::group`

This definition installs or removes yum package group.

#### Examples

##### Sample usage:

```puppet
yum::group { 'X Window System':
  ensure  => 'present',
}
```

#### Parameters

The following parameters are available in the `yum::group` defined type:

* [`ensure`](#ensure)
* [`timeout`](#timeout)
* [`install_options`](#install_options)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'installed', 'latest', 'absent', 'purged']`

specifies if package group should be present (installed) or absent (purged)

Default value: `'present'`

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer]`

exec timeout for yum groupinstall command

Default value: ``undef``

##### <a name="install_options"></a>`install_options`

Data type: `Array[String[1]]`

options provided to yum groupinstall command

Default value: `[]`

### <a name="yuminstall"></a>`yum::install`

Installs/removes rpms from local file/URL via yum install command.

* **Note** This can be better than using just the rpm provider because it will pull all the dependencies.

#### Examples

##### Sample usage:

```puppet
yum::install { 'epel-release':
  ensure => 'present',
  source => 'https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm',
}
```

#### Parameters

The following parameters are available in the `yum::install` defined type:

* [`source`](#source)
* [`ensure`](#ensure)
* [`timeout`](#timeout)

##### <a name="source"></a>`source`

Data type: `String`

file or URL where RPM is available

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'installed', 'absent', 'purged']`

the desired state of the package

Default value: `'present'`

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer]`

optional timeout for the installation

Default value: ``undef``

### <a name="yumplugin"></a>`yum::plugin`

This definition installs Yum plugin.

#### Examples

##### Sample usage:

```puppet
yum::plugin { 'versionlock':
  ensure  => 'present',
}
```

#### Parameters

The following parameters are available in the `yum::plugin` defined type:

* [`ensure`](#ensure)
* [`pkg_prefix`](#pkg_prefix)
* [`pkg_name`](#pkg_name)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

specifies if plugin should be present or absent

Default value: `'present'`

##### <a name="pkg_prefix"></a>`pkg_prefix`

Data type: `Optional[String]`

the package prefix for the plugins

Default value: ``undef``

##### <a name="pkg_name"></a>`pkg_name`

Data type: `Optional[String]`

the actual package name

Default value: ``undef``

### <a name="yumpost_transaction_action"></a>`yum::post_transaction_action`

Creates post transaction configuratons for dnf or yum.

* **See also**
  * https://dnf-plugins-core.readthedocs.io/en/latest/post-transaction-actions.html
    * DNF Post Transaction Items

#### Examples

##### Touch a file when ssh is package is updated, installed or removed.

```puppet
yum::post_transaction_action{'touch file on ssh package update':
  key     => 'openssh-*',
  state   => 'any',
  command => 'touch /tmp/openssh-installed',
}
```

#### Parameters

The following parameters are available in the `yum::post_transaction_action` defined type:

* [`action`](#action)
* [`key`](#key)
* [`state`](#state)
* [`command`](#command)

##### <a name="action"></a>`action`

Data type: `String[1]`

Name variable a string to label the rule

Default value: `$title`

##### <a name="key"></a>`key`

Data type: `Variant[Enum['*'],Yum::RpmNameGlob,Stdlib::Unixpath]`

Package name, glob or file name file glob.

##### <a name="state"></a>`state`

Data type: `Enum['install', 'update', 'remove', 'any', 'in', 'out']`

Can be `install`, `update`, `remove` or `any` on YUM based systems.
Can be `in`, `out` or `any` on DNF based systems.

Default value: `'any'`

##### <a name="command"></a>`command`

Data type: `String[1]`

The command to run

### <a name="yumversionlock"></a>`yum::versionlock`

Locks package from updates.

* **Note** The resource title must use the format
By default on CentOS 7 the following format is used.
"%{EPOCH}:%{NAME}-%{VERSION}-%{RELEASE}.%{ARCH}".  This can be retrieved via
the command `rpm -q --qf '%{EPOCH}:%{NAME}-%{VERSION}-%{RELEASE}.%{ARCH}'.
If "%{EPOCH}" returns as '(none)', it should be set to '0'.  Wildcards may
be used within token slots, but must not cover seperators, e.g.,
'0:b*sh-4.1.2-9.*' covers Bash version 4.1.2, revision 9 on all
architectures.
By default on CentOS 8 and newer the resource title  to just set the
package name.
If a version is set on CentOS 7 then it behaves like CentOS 8

* **See also**
  * http://man7.org/linux/man-pages/man1/yum-versionlock.1.html

#### Examples

##### Sample usage on CentOS 7

```puppet
yum::versionlock { '0:bash-4.1.2-9.el7.*':
  ensure => present,
}
```

##### Sample usage on CentOS 8

```puppet
yum::versionlock { 'bash':
  ensure => present,
  version => '4.1.2',
  release => '9.el8',
  epoch   => 0,
  arch    => 'noarch',
}
```

##### Sample usage on CentOS 7 with new style version, release, epoch, name parameters.

```puppet
yum::versionlock { 'bash':
  ensure => present,
  version => '3.1.2',
  release => '9.el7',
  epoch   => 0,
  arch    => 'noarch',
}
```

#### Parameters

The following parameters are available in the `yum::versionlock` defined type:

* [`ensure`](#ensure)
* [`version`](#version)
* [`release`](#release)
* [`arch`](#arch)
* [`epoch`](#epoch)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'exclude']`

Specifies if versionlock should be `present`, `absent` or `exclude`.

Default value: `'present'`

##### <a name="version"></a>`version`

Data type: `Optional[Yum::RpmVersion]`

Version of the package if CentOS 8 mechanism is used. This must be set for dnf based systems (e.g CentOS 8).
If version is set then the name var is assumed to a package name and not the full versionlock string.

Default value: ``undef``

##### <a name="release"></a>`release`

Data type: `Yum::RpmRelease`

Release of the package if CentOS 8 mechanism is used.

Default value: `'*'`

##### <a name="arch"></a>`arch`

Data type: `Variant[Yum::RpmArch, Enum['*']]`

Arch of the package if CentOS 8 mechanism is used.

Default value: `'*'`

##### <a name="epoch"></a>`epoch`

Data type: `Integer[0]`

Epoch of the package if CentOS 8 mechanism is used.

Default value: `0`

## Functions

### <a name="yumbool2num_hash_recursive"></a>`yum::bool2num_hash_recursive`

Type: Puppet Language

This functions converts the Boolean values of a Hash to Integers,
either '0' or '1'.  It does this recursively, decending as far as the
language implemenation will allow.  Note that Structs and Arrays will
be ignored, even if they contain Hashes.

#### Examples

##### Usage

```puppet

Hash $foo = {
  bar => { 'a' => true, 'b' => 'b' },
  baz => false,
  qux => [{ 'c' => true }, { 'd' => false }],
}

yum::bool2num_hash_recursive($foo)

The above would return:

{
  bar => { 'a' => 1, 'b' => 'b' },
  baz => 0,
  qux => [{ 'c' => true }, { 'd' => false }],
}
```

#### `yum::bool2num_hash_recursive(Hash $arg)`

This functions converts the Boolean values of a Hash to Integers,
either '0' or '1'.  It does this recursively, decending as far as the
language implemenation will allow.  Note that Structs and Arrays will
be ignored, even if they contain Hashes.

Returns: `Hash`

##### Examples

###### Usage

```puppet

Hash $foo = {
  bar => { 'a' => true, 'b' => 'b' },
  baz => false,
  qux => [{ 'c' => true }, { 'd' => false }],
}

yum::bool2num_hash_recursive($foo)

The above would return:

{
  bar => { 'a' => 1, 'b' => 'b' },
  baz => 0,
  qux => [{ 'c' => true }, { 'd' => false }],
}
```

##### `arg`

Data type: `Hash`

The hash on which to operate

## Data types

### <a name="yumrpmarch"></a>`Yum::RpmArch`

Output of `rpm -q --queryformat '%{arch}\n' package`

* **See also**
  * https://github.com/rpm-software-management/rpm/blob/master/rpmrc.in

Alias of

```puppet
Enum['noarch', 'x86_64', 'i386', 'aarch64', 'arm', 'ppc64', 'ppc64le', 'sparc64', 'ia64', 'alpha', 'ip', 'm68k', 'mips', 'mipsel', 'mk68k', 'mint', 'ppc', 'rs6000', 's390', 's390x', 'sh', 'sparc', 'xtensa']
```

### <a name="yumrpmname"></a>`Yum::RpmName`

Can be alphanumeric or contain `.` `_` `+` `%` `{` `}` `-`.
Output of `rpm -q --queryformat '%{name}\n package`
Examples python36-foobar, netscape

Alias of

```puppet
Pattern[/\A([0-9a-zA-Z\._\+%\{\}-]+)\z/]
```

### <a name="yumrpmnameglob"></a>`Yum::RpmNameGlob`

Can be alphanumeric or contain `.` `_` `+` `%` `{` `}` `-` `*`.
Examples python36-*, *netscape

Alias of

```puppet
Pattern[/\A([*0-9a-zA-Z\._\+%\{\}-]+)\z/]
```

### <a name="yumrpmrelease"></a>`Yum::RpmRelease`

It may not contain a dash.
Output of `rpm -q --queryformat '%{release}\n' package`.
Examples 3.4 3.4.el6, 3.4.el6_2

* **See also**
  * http://ftp.rpm.org/max-rpm/ch-rpm-file-format.html

Alias of

```puppet
Pattern[/\A([^-]+)\z/]
```

### <a name="yumrpmversion"></a>`Yum::RpmVersion`

It may not contain a dash.
Output of `rpm -q --queryformat '%{version}\n' package`.
Examples 3.4, 2.5.alpha6

* **See also**
  * http://ftp.rpm.org/max-rpm/ch-rpm-file-format.html

Alias of

```puppet
Pattern[/\A([^-]+)\z/]
```

### <a name="yumversionlockstring"></a>`Yum::VersionlockString`

This type matches strings appropriate for use with yum-versionlock.
Its basic format, using the `rpm(8)` query string format, is
`%{EPOCH}:%{NAME}-%{VERSION}-%{RELEASE}.%{ARCH}`.  As a Regex, it
breaks down into five distinct parts, plus the seperators.

  EPOCH: An unsigned integer
  type Yum::PackageEpoch   = Regexp[/[0-9]\*]+/]

  NAME: Any valid package name (see https://github.com/rpm-software-management/rpm/blob/master/doc/manual/spec)
  type Yum::PackageName    = Regexp[/[0-9a-zA-Z\._\+%\{\}\*-]+/]

  VERSION: Any valid version string. The only limitation here, according to the RPM manual, is that it may not contain a dash (`-`).
  type Yum::PackageVersion = Regexp[/[^-]+/]

  RELEASE: Any valid release string. Only limitation is that it is not a dash (`-`)
  type Yum::PackageRelease = Regexp[/[^-]+/]

lint:ignore:140chars
  ARCH: Matches a string such as `el7.x86_64`.  This is actuall two sub-expressions.  See below.
  type Yum::PackageArch    = Regexp[/([0-9a-zZ-Z_\*]+)(?:\.(noarch|x86_64|i386|arm|ppc64|ppc64le|sparc64|ia64|alpha|ip|m68k|mips|mipsel|mk68k|mint|ppc|rs6000|s390|s390x|sh|sparc|xtensa|\*))?/]
lint:endignore

The `%{ARCH}` sub-expression is composed of two sub-expressions
separated by a dot (`.`), where the second part is optional.  The RPM
specification calls the first field the `DistTag`, and the second the
`BuildArch`.

   DistTag: Any string consiting of only letters, numbers, or an underscore, e.g., `el6`, `sl7`, or `fc24`.
   type Yum::PackageDistTag   = Regexp[/[0-9a-zZ-Z_\*]+/]

lint:ignore:140chars
   BuildArch: Any string from the list at https://github.com/rpm-software-management/rpm/blob/master/rpmrc.in.  Strings are roughly listed from most common to least common to improve performance.
   type Yum::PackageBuildArch = Regexp[/noarch|x86_64|i386|arm|ppc64|ppc64le|sparc64|ia64|alpha|ip|m68k|mips|mipsel|mk68k|mint|ppc|rs6000|s390|s390x|sh|sparc|xtensa/]
lint:endignore

wildcard characters may not span the fields, may not cover the
seperators.  This is an undocumented but tested limitation of
yum-versionlock.

lint:ignore:140chars

* **Note** Each field may contain wildcard characters (`*`), but the

#### Examples

##### A complete, well-formed string: `0:bash-4.1.2-9.el6_2.x86_64'

```puppet

```

##### A well-formed string that has dropped the optional BuildArch sub-field: `0:bash-4.1.2-9.el6_2`

```puppet

```

##### A well-formed string using wildcards: `*0:bash*-4.*-*.*`

```puppet

```

##### An invalid string (wildcard spans the VERSION and RELEASE fields): `0:bash-4.*-el6.x86_64

```puppet

```

##### An invlaid string (wildcard spans the VERSION, RELEASE, and ARCH fields): `0:bash-*`

```puppet

```

Alias of

```puppet
Pattern[/^([0-9\*]+):([0-9a-zA-Z\._\+%\{\}\*-]+)-([^-]+)-([^-]+)\.(([0-9a-zZ-Z_\*]+)(?:\.(noarch|x86_64|i386|arm|ppc64|ppc64le|sparc64|ia64|alpha|ip|m68k|mips|mipsel|mk68k|mint|ppc|rs6000|s390|s390x|sh|sparc|xtensa|\*))?)$/]
```

## Tasks

### <a name="init"></a>`init`

Allows you to perform yum functions

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[update, upgrade, 'list updates']`

Action to perform 

##### `quiet`

Data type: `Optional[Boolean]`

Run without output 

